#!/bin/sh

# index.cgi v1.07 (28th february 2011) by Andy Davison
#  birdslikewires.co.uk

#  Index page for the little app launcher.


if [ "$SSH_CLIENT" == "" ]; then
	echo "Content-type: text/html"
	echo ""
fi


### Setup ###

[ -d /media/logs ] || mkdir /media/logs
[ -f /media/launcher/apps/count ] || echo 0 > /media/launcher/apps/count

## Alter port if P'n'P is installed.
PORT=`cat /media/launcher/port`
if [ "$PORT" == "80" ] && [ -d /media/gforums ]; then
	PORT="8080"
	echo $PORT > /media/launcher/port
fi

DAY=`date '+%A, %B %d'`
TIME=`date '+%H:%M'`
APPS=`find /media/launcher/apps -type f \( -name 'runner.cgi' -o -name 'trigger.cgi' \) | sort`
APPC=`echo "$APPS" | egrep -c 'trigger.cgi'`
APPE=`cat /media/launcher/apps/count`
MONGOOSELAUNCH="/media/launcher/mongoose -r /media/launcher -p $PORT -a /media/logs/mongoose_access.log -e /media/logs/mongoose_error.log -E PATH=/bin:/usr/bin,HOME=/ 2>&1 >/dev/null &"
MONGOOSERUNNING=`ps | grep -v grep | grep /media/launcher/mongoose | awk -F\  '{print $1}'`

## If we have a copy of Mongoose, make sure that it's set to load.
MONGOOSEPRESENT=`cat /etc/init.d/rcS | grep "$MONGOOSELAUNCH"`
if [ "$MONGOOSEPRESENT" == "" ] && [ -f /media/launcher/mongoose ]; then
	
	# Kill any existing /media/launcher/mongoose instances.
	if [ "$MONGOOSERUNNING" != "" ]; then
		echo $MONGOOSERUNNING | while read mongoosepid; do
			kill $mongoosepid
		done
	fi
	
	cat /etc/init.d/rcS | grep -v "/media/launcher/mongoose -r /media/launcher" > /etc/init.d/rcS_update
	echo "$MONGOOSELAUNCH" >> /etc/init.d/rcS_update
	mv /etc/init.d/rcS_update /etc/init.d/rcS
	chmod +x /etc/init.d/rcS
		
fi

## Make sure mongoose is running.
if [ "$MONGOOSERUNNING" == "" ] && [ -f /media/launcher/mongoose ]; then 
	/media/launcher/mongoose -r /media/launcher -p $PORT -a /media/logs/mongoose_access.log -e /media/logs/mongoose_error.log -E PATH=/bin:/usr/bin,HOME=/ 2>&1 >/dev/null &
fi

## Make sure the applications.xml file is up to date.
cat /media/appshop/applications.xml | grep -v 'id="launcher"' > /media/appshop/applications.xml_backup
cat /media/appshop/applications.xml_backup | grep -v '</applications>' > /media/appshop/applications.xml_update

echo "$APPS" | while read apps; do

	app=`echo $apps | awk -F\/ '{print $5}'`
	apptype=`echo $apps | awk -F\/ '{print $6}'`
	appalready=`cat /media/appshop/applications.xml_update | grep "$app"`
	
	if [ "$apptype" == "trigger.cgi" ] && [ "$appalready" == "" ]; then
		#echo "  <app static=\"1\" id=\"launcher\" loc=\"http://localhost:$PORT/apps/$app/\" icon=\"icon.swf\" app=\"$apptype\"/>" >> /media/appshop/applications.xml_update
		echo "  <app id=\"launcher\" static=\"1\" ext=\"1\" standalone=\"1\" loc=\"/media/launcher/apps/$app/\" icon=\"icon.swf\" app=\"/media/launcher/apps/$app/$apptype\"/>" >> /media/appshop/applications.xml_update
		
		#<app id="launcher" static="1" ext="1" standalone="1" loc="/media/launcher/apps/SqueezePlay/" icon="icon.swf" app="/media/launcher/apps/SqueezePlay/trigger.cgi"/>
		
	fi
	
done

echo "</applications>" >> /media/appshop/applications.xml_update
mv /media/appshop/applications.xml_update /media/appshop/applications.xml

## If the number of launchers with trigger.cgi files has changed, refresh tango.
if [ "$APPC" != "$APPE" ]; then
	killall tango
	echo "$APPC" > /media/launcher/apps/count
fi


### Output ###
if [ "$SSH_CLIENT" != "" ]; then
	
	if [ "$APPC" != "$APPE" ]; then
		echo "Launcher list updated."
	fi
	
	if [ "$APPS" == "" ]; then
		echo "There are no launchers installed at the moment."
	fi
	
else
	
	echo '<!DOCTYPE html>'
	echo '<html lang="en-GB">'
	echo '	<head>'
	echo "		<title>Joggler</title>"
	echo '		<link rel="stylesheet" href="layout.css" type="text/css" media="screen" />'
	echo '	</head>'
	echo '	<body>'

	echo '	<div id="interface">'
	echo "		<div id=\"datetime\"><h2><span class=\"date_day\">$DAY | </span><span class=\"date_time\">$TIME</span></h2></div>"

	echo '		<div id="interactive">'


	## Here we look for the launchers.
	if [ "$APPS" != "" ]; then
		echo "$APPS" | while read apps; do

			app=`echo $apps | awk -F\/ '{print $5}'`
			apptidy=`echo $app | sed 's/_/ /'`
			apptype=`echo $apps | awk -F\/ '{print $6}'`
	
			if [ "$apptype" == "runner.cgi" ]; then
				echo "		<div class=\"icon\"><a href=\"apps/$app/runner.cgi\"><embed src=\"apps/$app/icon.swf\"></embed></a><div class=\"iconname\"><p>$apptidy</p></div></div>"
			elif [ "$apptype" == "trigger.cgi" ]; then
				echo "		<div class=\"icon\"><a href=\"launcher.cgi?$app\"><embed src=\"apps/$app/icon.swf\"></embed></a><div class=\"iconname\"><p>$apptidy</p></div></div>"
			fi
	
		done
	else
		echo "		<h3 class=\"nolaunchers\">There are no launchers installed at the moment.</h3>"
	fi


	echo '		</div>'

	echo '	</div>'

	echo '	</body>'
	echo '</html>'

fi